annalist
========

(Short README for PyPI - a longer version can be found at https://github.com/gklyne/annalist)

Free-form web data notebook - "Data management for little guys"

Annalist is a *Linked Data Notebook*, supporting collection, organization and sharing of structured and semi-structured data.  The name "Annalist" derives from "`a person who writes annals <http://www.oxforddictionaries.com/definition/english/annalist>`_".

Goals
-----

The overall goal of Annalist is to make it easy for individuals and small teams to create and explore linked data on the web, without requiring software development.

* Easy data: out-of-box data acquisition, modification and organization of small data records.
* Flexible data: new record types and fields can be added as-required.
* Sharable data: use textual, easy to read file formats that can be shared by web, email, file transfer, version management system, memory stick, etc.
* Remixable data: records that can be first class participants in a wider ecosystem of linked data, with links in and links out.

Demo system home page
---------------------

For general information about Annalist, and demonstration system links, see the [Annalist demonstration system home page](http://annalist.net/).

Status
------

For current release status, see https://github.com/gklyne/annalist/blob/master/documents/release-notes/release-v0.1.md

